<!-- markdownlint-disable-next-line first-line-h1 -->
##### Project

::PROJECT-NAME

##### Internal Release Number

::X.Y.Z

##### Related Documents

- [SRS](SRS) > [Feature Set](Feature-Set) > Features
- [Feature format](Feature-Format)
- [Project proposal](Proposal) > [User needs](User-Needs)
- [SRS](SRS) > [Use case suite](Use-Case-Suite)
- ::LINKS TO RELEVANT STANDARDS
- ::LINKS TO OTHER DOCUMENTS

---

**Process impact:** This is a set of detailed feature descriptions.

_TODO: For each feature listed in the [feature set](Feature-Set),
give a detailed description of the feature here. Describe each feature
in enough detail that it could be implemented by any member of the
development team (not only someone who already informally knows what to
do)._

_TIP: Start with a short textual description of each feature. Then, add
more formal information as needed to make each description precise and
unambiguous. E.g.,_

- _Precisely define valid inputs, and error handling_
- _Specify data structures with UML or logical schema_
- _Specify UI aspects of features with tiny mock-ups_
- _Specify key decisions with decision trees or tables_
- _Specify key algorithms with pseudo-code or flow charts_
- _Specify state-based behavior with state machines or tables_
- _Specify sequences of events with scenario diagrams_

---

### ::F-00: Site Configuration

Priority: ::Essential

Effort: ::Days

Risk: ::Safe

Functional area(s): ::Administration

Use case(s): ::[UC-00](Use-Cases#UC-00) [UC-11](Use-Cases#UC-11)

Description:

::The site administrators will be able to configure:

- ::The site appearance by choosing a predefined CSS file
- ::Whether the site makes new clans public or private by default
- ::The email address to be used to send critical error reports

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-01: User registration

Priority: **::Essential**

Effort: ::Days

Risk: ::Safe

Functional area(s): ::Administration

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:
:: Visitors can come to the site and register themselves. They must provide the following information:

- ::username
- ::email address (twice to catch typos)
- ::real name

Precise Details:

- ::username must be unique (not equal to any other existing user name)
- ::username must be of the form ~~~[a-zA-Z0-9]{2,16}~~~ and is not case sensitive
- ::email address must be of the form ~~~[-a-zA-Z0-9_.]{2,16}@[-a-zA-Z0-9_.]{6,64}~~~
- ::both entries of the email address must match
- ::email address will be verified by sending the user's initial password there
- ::real name must not be empty
- ::leading and trailing spaces are stripped from all fields

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-02: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:
:: 1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-03: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-10: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-11: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-12: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-13: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-20: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-21: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-22: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-23: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-30: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-31: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-32: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION

---

### ::F-33: FEATURE NAME

Priority: ::Essential | Expected | Desired | Optional

Effort: ::Months | Weeks | Days | Hours

Risk: ::Dangerous | 3-Risks | 2-Risks | 1-Risk | Safe

Functional area(s): ::WORD, WORD, WORD

Use case(s): ::[UC-01](Use-Cases#UC-01)

Description:

::1-4 PARAGRAPHS. USE BULLETS OR TABLES TO ORGANIZE INFORMATION. LINK TO WORKSHEETS OR ADDITIONAL INFORMATION.

Precise Details:

- ::LOGICAL CONSTRAINT
- ::LOGICAL CONSTRAINT

Notes and Questions:

- ::NOTE
- ::QUESTION
